<?php

/**
 * @version    1.3.3
 * @package    com_jphpx
 * @author     Joachim Schmidt <joachim.schmidt@oberquembach.de>
 * @copyright  2021 Joachim Schmidt
 * @license    GNU General Public License Version 2 or later
 */
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \Joomla\CMS\Version;

$joomla_version = new Version();
$version = $joomla_version->getShortVersion();

HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('formbehavior.chosen', 'select');
HTMLHelper::_('behavior.keepalive');

$document = Factory::getApplication()->getDocument();
$css = Uri::root() . 'media/com_jphpx/css/form.css';
$confirm_css = Uri::root() . 'media/com_jphpx/css/jquery-confirm.min.css';
$confirm_js = Uri::root() . 'media/com_jphpx/js/jquery-confirm.min.js';
if (version_compare($version, "4.0.0", '<'))
{
  HTMLHelper::_('behavior.formvalidation');
  $document->addStyleSheet($css);
  $document->addStyleSheet($confirm_css);
  $document->addScript($confirm_js);
  $style = ".container { width: 30% !important;}";
  $document->addStyleDeclaration($style);
}
else
{
  HTMLHelper::_('behavior.formvalidator');
  $wa = Factory::getApplication()->getDocument()->getWebAssetManager();
  $wa->registerAndUseStyle("jphpx_code", $css);
  $wa->registerAndUseStyle("confirm_css", $confirm_css);
  $wa->registerAndUseScript("confirm_js", $confirm_js);
}

?>

<script type="text/javascript">
	js = jQuery.noConflict();
	js(document).ready(function () {
		
	});

	Joomla.submitbutton = function (task) {
		if (task == 'jphpx_code.cancel') {
			Joomla.submitform(task, document.getElementById('jphpx_code-form'));
		}
		else {

            var title = '<?php echo $this->escape(Text::_('JPHPX_ERROR')); ?>';
			var val=document.getElementById('jform_access').value;
            if ((val > 1 || val < 0) || isNaN(Number(val)) )
            {
               jQuery.alert({ title: title, type: 'red', theme: 'light', content: '<?php echo $this->escape(Text::_('JPHPX_VALIDATION_BOOLEAN')); ?>'});
               return false;
            }
            
    		val=document.getElementById('jform_published').value;
    	    if ((val > 1 || val < 0) || isNaN(Number(val)) )
            {
               jQuery.alert({ title: title, type: 'red', theme: 'light', content: '<?php echo $this->escape(Text::_('JPHPX_VALIDATION_BOOLEAN')); ?>'});
               return false;
            }
			
			if (task != 'jphpx_code.cancel' && document.formvalidator.isValid(document.getElementById('jphpx_code-form'))) {
				
				Joomla.submitform(task, document.getElementById('jphpx_code-form'));
			}
			else {
                 jQuery.alert({ title: title, type: 'red', theme: 'light', content: '<?php echo $this->escape(Text::_('JGLOBAL_VALIDATION_FORM_FAILED')); ?>'});
		   }
		}
	}
</script>

<form
	action="<?php echo Route::_('index.php?option=com_jphpx&layout=edit&id=' . (int) $this->item->id); ?>"
	method="post" enctype="multipart/form-data" name="adminForm" id="jphpx_code-form" class="form-validate form-horizontal">
       
	<img src='<?php echo  Uri::root(true) ?>/media/com_jphpx/images/jphpx_logo.png' alt='jphp logo' style='margin-top:-10px;margin-right:8px;float: left;' />

    <?php echo HTMLHelper::_('bootstrap.startTabSet', 'myTab', array('active' => 'jphpx_code')); ?>
	<?php echo HTMLHelper::_('bootstrap.addTab', 'myTab', 'jphpx_code', Text::_('COM_JPHPX_TAB_JPHPX_CODE', true)); ?>
	<div class="row-fluid">
		<div class="span10 form-horizontal">
			<fieldset class="adminform">
				<legend><?php echo "<br>" . Text::_('COM_JPHPX_TAB_JPHPX_CODE_LEGEND'); ?></legend>
				<?php echo $this->form->renderField('title'); ?>
				<?php echo $this->form->renderField('source'); ?>
				<?php echo $this->form->renderField('access'); ?>
				<?php echo $this->form->renderField('published'); ?>
			</fieldset>
		</div>
	</div>
	<?php echo HTMLHelper::_('bootstrap.endTab'); ?>
	<input type="hidden" name="jform[id]" value="<?php echo $this->item->id; ?>" />
		

	<?php $this->ignore_fieldsets = array('general', 'info', 'detail', 'jmetadata', 'item_associations', 'accesscontrol'); ?>
	<?php echo LayoutHelper::render('joomla.edit.params', $this); ?>
	
	<?php echo HTMLHelper::_('bootstrap.endTabSet'); ?>

	<input type="hidden" name="task" value=""/>
	<?php echo HTMLHelper::_('form.token'); ?>

</form>
