<?php
/**
 # Sudoku.php
 #
 # Run Sudoku app with Joomla's extension "jphpx"
 #
 # @author Joachim Schmidt - joachim.schmidt@jschmidt-systemberatung.de
 # @copyright Copyright (C) 2021 Joachim Schmidt. All rights reserved.
 # @license	 http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 # @formatter:off
 #
 # change activity:
 #        01.09.2022: used jphpx_id from sudoku.ini to set id in ajax-url (seei line# 26)
 #        12.09.2022: changed $_REQUEST to  joomla's  input-API
 #        24.09.2022: added support for using own sudoku puzzles
 */
	
    defined('_JEXEC') or die('can only run under Joomla with extension &quot;jphpx&quot;!');
    use \Joomla\CMS\Factory;
    use \Joomla\CMS\HTML\HTMLHelper;
    use \Joomla\CMS\Uri\Uri;
    use \Joomla\CMS\Version;
           
    HTMLHelper::_('jquery.framework');
    $base = JPATH_ROOT . "/components/com_jphpx/demo";
    $text = parse_ini_file ($base . "/sudoku.ini", true );
    $url =  URI::root (true) . "/index.php?option=com_ajax&plugin=jphpx&group=system&format=raw&id=" . $text['jphpx_id'];
   
    $joomla_version = new Version();
    if (version_compare($joomla_version->getShortVersion(), '4.0', '>='))
    {
        $wa = Factory::getApplication()->getDocument()->getWebAssetManager();
        $wa->registerAndUseStyle("sudoku", "media/com_jphpx/css/style.css");
        $wa->registerAndUseScript("sudoku1", "media/com_jphpx/js/sudoku.js");
        $wa->registerAndUseScript("sudoku2", "media/com_jphpx/js/printThis.js");
    }
    else
    {
        $document = Factory::getApplication()->getDocument();
        $document->addStylesheet(Uri::root(true) . "/media/com_jphpx/css/style.css");
        $document->addScript(Uri::root(true) . "/media/com_jphpx/js/sudoku.js");
        $document->addScript(Uri::root(true) . "/media/com_jphpx/js/printThis.js");
    }
     
    $notes =  parse_ini_file ($base . "/" . $text['notes_ini'], true);
    $valid_languages = $text['languages'];
     
    $tmp = Factory::getApplication()->getLanguage();
    $lang = substr($tmp->getTag(), 0, 2);
    
    if (strpos($valid_languages, $lang) === false)
        $lang = "en";

    $text = $text[$lang];
    $notes = $notes[$lang];
    
    $input = Factory::getApplication()->input;
    if ( $input->get('sudoku') )
        $parm = "&sudoku=" . $input->getInt('sudoku');
    else
        $parm = "&sudoku=noid";
    
     if ( $input->get('level') )
         $parm = "&level=" .  $input->getInt('level');
     
?>
<div id="language" style="display: none;"><?php echo $lang; ?></div>
<div id="sudoku-container" class="sudoku-container">
 <div class="bubble">
  <div id="sudokuid" class="rectangle"><h2>Sudoku -</h2></div>
  <div class="triangle-l"></div>
  <div class="triangle-r"></div>
  <div class="sudoku-info">
   <div id="sudoku" class="center">
    <div id='msgbox_content' style='display: none'><?php echo $text['success_msg']; ?></div>
    <div id='msgbox_content2' style='display: none'><?php echo $text['own_sudoku_msg']; ?></div>
<?php
	$html = "\n<table class='sudoku' id='sudoku-grid'>";
	$count = 0;
	$check = "onkeyup='checkValue($count, true, true)'";
	for ($x = 0; $x < 9; $x++)
	{
		$html .= "\n<tr>";
		for ($y = 0; $y < 9; $y++)
		{
			$class = "cell";
			if ($y == 2 || $y == 5)
				$class = "cell cell-right";
			
			if ($x == 2 || $x == 5)
				$class = "cell cell-bottom";
			
			if (($y == 2 && $x == 2) || ($y == 2 && $x == 5))
				$class = "cell cell-both";
			
			if (($y == 5 && $x == 2) || ($y == 5 && $x == 5))
				$class = "cell cell-both";

			$check = "onkeyup='checkValue($count, true, true)'";

			$html .= "\n<td class='" . $class . "'>";
			$html .= "\n <div id='candidates" . $count . "' class='overlay'></div>";
			$html .= "\n <input type='text' id='i" . $count . "' name='i" . $count . "' " .
				  "value='' size='1' maxlength='1' class='cell' $check />\r\n";
			$html .= "</td>";
			$count ++;
		}
		$html .= "</tr>";
	}
	$html .= "\n</table>";
	echo $html;
?>
<br />
  <form id="form" class="sudoku-form" name="form" action="none">
    <input type="hidden" name="sudoku" value="" />
    <input  class="sudokubutton" id="button1" type="button" value="<?php echo $text['new_sudoku']; ?>"
      onclick="getPuzzle('<?php echo $url . "','null"; ?>')" />
    <input class="sudokubutton" id="button2" type="button" value="<?php echo $text['solution']; ?>" onclick="showSolution()" />
    <input class="sudokubutton" id="button3" type="button" value="<?php echo $text['print']; ?>"
        onclick="jQuery('#sudoku-container').printThis({ loadCSS: '<?php  Uri::root(true); ?>/media/com_jphpx/css/print.css' });" />
     <input  class="sudokubutton" style="display: none;" id="button4" type="button" value="&nbsp;&nbsp;OK&nbsp;&nbsp" onclick="setOwnPuzzle()" />
     <label id="lbl_help"><input type="checkbox" id="help" name="help" value="0" onclick="checkValues()" />&nbsp;<?php echo $text['help']; ?>&nbsp;</label>
     <input type="checkbox" id="check" name="check" value="1" checked="checked" onclick="checkValues()" />&nbsp;<?php echo $text['check']; ?>&nbsp;
     <br /> <br /> <b style="padding-left: 5px;">Level:</b>&nbsp;
     <label> <input type="radio" id="level0" name="level" value="0" checked="checked" />&nbsp;<?php echo $text['level0']; ?>&nbsp; </label>
     <label> <input type="radio" id="level1" name="level" value="1" />&nbsp;<?php echo $text['level1']; ?>&nbsp;</label>
     <label> <input type="radio" id="level2" name="level" value="2" />&nbsp;<?php echo $text['level2']; ?>&nbsp;</label>
     <label> <input type="radio" id="level3" name="level" value="3" />&nbsp;<?php echo $text['own_sudoku']; ?>&nbsp;</label>
 </form>
    <div id="messages" class="sudoku-messages">&nbsp;</div>
</div>

<?php
$script = "\njQuery(document).ready(function() {";
$script .= "\n   getPuzzle('" .  $url . "','" .$parm . "');";
$script .= "\n});";
$document = Factory::getApplication()->getDocument();
$document->addCustomTag("<script type='text/javascript'>" . $script . "</script>");
?>

</div>
 </div>
</div>
<div id="notes">
<?php echo $notes['notes']; ?>
</div>
